.. Multi-Platform Quantum Programming documentation master file, created by
   sphinx-quickstart on Mon Feb 13 11:37:55 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to the Multi-Platform Quantum Programming library's documentation!
==========================================================================

This is the reference manual for our Multi-Platform Quantum Programming library 
(in short MPQP). You will find here all the elements needed to be able to use it
fluently.

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   getting-started
   circuit
   instructions
   execution
   execution-extras
   vqa
   qasm
   tools
   changelog

Α full index can be found in the :ref:`genindex` page and a map of the module
can be found in the :doc:`all-modules` page.
